service system/modules {
	need = system/initial system/mountroot

	start {
		# Set the path
		export PATH=/bin:/sbin:/usr/bin:/usr/sbin

		# Read functions
		. /etc/rc.d/init.d/functions

		# And sysconfig
		if [ -r /etc/sysconfig/system ]; then
			. /etc/sysconfig/system
		else
			VSERVER=no
		fi

		if [ "$VSERVER" = "yes" ]; then
			exit 0
		fi

		# Should not fail if kernel do not have module
		# support compiled in ...
		if [ ! -f /proc/modules ]; then
			USEMODULES=
		elif ! grep -iq nomodules /proc/cmdline; then
			USEMODULES=y
		else
			USEMODULES=
		fi

		# Run depmod if RUN_DEPMOD != "no" and:
		# a) user requested or RUN_DEPMOD="";
		# b) modules.dep is missing
		# c) modules.dep is older than /etc/modules.conf or /lib/modules/`uname -r`
		if ! is_no "$RUN_DEPMOD" && [ -n "$USEMODULES" ]; then
				if is_yes "$RUN_DEPMOD" || [ -z "$RUN_DEPMOD" ]; then
				run_cmd "Finding module dependencies" depmod -a
			elif [ "$RUN_DEPMOD" = "ifmissing" ]; then
				run_cmd "Finding module dependencies" depmod -A
			fi
		fi

		if [ -f /proc/sys/kernel/modprobe ]; then
			if [ -n "$USEMODULES" ]; then
				sysctl -w kernel.modprobe="/sbin/modprobe" >/dev/null 2>&1
				sysctl -w kernel.hotplug="/sbin/hotplug" >/dev/null 2>&1
			else
				# We used to set this to NULL, but that causes
				# 'failed to exec' messages"
				sysctl -w kernel.modprobe="/bin/true" >/dev/null 2>&1
				sysctl -w kernel.hotplug="/bin/true" >/dev/null 2>&1
			fi
		fi

		# Initialize USB controllers
		usb=0
		if ! grep -iq "nousb" /proc/cmdline 2>/dev/null && ! grep -q "usb" /proc/devices 2>/dev/null ; then
			aliases=$(/sbin/modprobe -c | awk '/^alias usb-controller/ { print $3 }')
			if [ -n "$aliases" -a "$aliases" != "off" ] ; then
				/sbin/modprobe -k usbcore
				for alias in $aliases ; do
					[ "$alias" = "off" ] && continue
					run_cmd "$(nls 'Initializing USB controller') ($alias)" /sbin/modprobe $alias
				done
				[ $? -eq 0 -a -n "$aliases" ] && usb=1
			fi
			if grep -iq "usb" /proc/devices 2>/dev/null ; then
				usb=1
			fi
		fi

		if [ "$usb" = "1" -a ! -f /proc/bus/usb/devices ]; then
			run_cmd "Mounting USB filesystem" mount -t usbfs usbfs /proc/bus/usb
		fi

		needusbstorage=
		if [ "$usb" = "1" ]; then
			needusbstorage=$(LC_ALL=C cat /proc/bus/usb/devices 2>/dev/null|grep -e "^I.*Cls=08")
			if [ "$(kernelverser)" -lt "002006" ]; then
				LC_ALL=C grep -q 'hid' /proc/bus/usb/drivers 2> /dev/null || run_cmd "Initializing USB HID interface" modprobe hid 2> /dev/null
				mouseoutput=$(cat /proc/bus/usb/devices 2>/dev/null|grep -E "^I.*Cls=03.*Prot=02")
				kbdoutput=$(cat /proc/bus/usb/devices 2>/dev/null|grep -E "^I.*Cls=03.*Prot=01")
				if [ -n "$kbdoutput" ]; then
					run_cmd "Initializing USB keyboard" modprobe keybdev
				fi
				if [ -n "$mouseoutput" ]; then
					run_cmd "Initializing USB mouse" modprobe mousedev
				fi
			fi
		fi


		# Load usb storage here, to match most other things
		if [ -n "$needusbstorage" ]; then
				modprobe -k usb-storage >/dev/null 2>&1
		fi

		# Load modules
		if [ -x /etc/rc.d/rc.modules ]; then
			/etc/rc.d/rc.modules
		fi

		exit 0
	}
}
